# -*- coding: utf-8 -*-

__name__ = "orbis_plugin_storage_html_pages"
__version__ = "2.3.1"
__author__ = "fabod, Roger Waldvogel"
__year__ = "2021"
__description__ = "The html_pages storage plugin for Orbis"
__license__ = "GPL2"
__min_python_version__ = "3.6"
__requirements_file__ = "requirements.txt"
__url__ = "https://github.com/orbis-eval/orbis_plugin_storage_html_pages"
__type__ = "plugin"

from .main import Main
